function [sys,x0,str,ts] = xyplotting(t,x,u,flag)
h=figure(1);
%
% Dispatch the flag.
%
switch flag,
  case 0
    [sys,x0,str,ts]=mdlInitializeSizes(h); % Initialization
  case 2
    sys = mdlUpdate(t,x,u,h);
  case { 1, 3, 4, 9 } % Unused flags
    sys = [];
  otherwise
    error(['Unhandled flag = ',num2str(flag)]); % Error handling
end
% End of csfunc.
%==============================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the 
% S-function.
%==============================================================
%
function [sys,x0,str,ts] = mdlInitializeSizes(h)
%
% Call simsizes for a sizes structure, fill it in and convert it 
% to a sizes array.
%
sizes = simsizes;
sizes.NumContStates  = 0;
sizes.NumDiscStates  = 2;
sizes.NumOutputs     = 0;
sizes.NumInputs      = 2;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;
sys = simsizes(sizes);
%
% Initialize the initial conditions.
%
x0 = [0;0];
str = [];
ts = [1 0];
%
% Plot initial function
%
set(h,'name','g(V)=\alpha si V<0; \beta sinon');
clf;
alpha=0.5;
beta=1.96;
V=-2:2;
gV=(alpha*(V<=0)+beta*(V>0)).*V;
plot(V,gV,'r-','LineWidth',2),hold on,
axis([-2,2,-4,4]),

global NextT deltaT
deltaT=100;
NextT=0;

% global aviobj
% aviobj = avifile('neurone2.avi')
% % aviobj.Compression = 'none';
% % aviobj.Quality = 100;
% frame = getframe(gca);
% aviobj = addframe(aviobj,frame);
% End of mdlInitializeSizes.
%
%==============================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%==============================================================
function sys = mdlUpdate(t,x,u,h)
p=get(h,'CurrentAxes');pp=get(p,'Children');
for i=1:length(pp),
    if isequal(get(pp(i),'type'),'line'),
        c=get(pp(i),'color');
        if c(3)==1,% i.e. ligne bleue
            ms=get(pp(i),'MarkerSize');
            if ms>1e-8,
                set(pp(i),'MarkerSize',0.5*ms),
            else
                delete(pp(i)),
            end,
        end,
    end,
end,

plot([x(1),u(1)],[x(2),u(2)],'--bs','LineWidth',2,...
                'Marker','o',...
                'MarkerEdgeColor','k',...
                'MarkerFaceColor','g',...
                'MarkerSize',8)

% global NextT deltaT
% if t>=NextT,
%     s=['000',int2str(NextT)];
%     l=length(s);
%     s=s((l-3):l);
%     fn=['alphabeta',s,'.eps'];
%     disp(fn)
%     print(h,'-depsc','-loose',fn),
%     NextT=NextT+deltaT;
% end,
            
% global aviobj
% frame = getframe(gca);
% aviobj = addframe(aviobj,frame);
% % global aviobj,aviobj=close(aviobj)
sys = [u(1);u(2)];
% End of mdlUpdate.
%
%==============================================================
% mdlOutputs
% Return the block outputs.
%==============================================================
%
%function sys = mdlOutputs(t,x,u,A,B,C,D)
%sys = [];
% End of mdlOutputs.
